@@ -3,8 +3,8 @@ import sys
 sys.path.append('../')
 sys.path.append('./')
 from gooey import Gooey, GooeyParser
-from comFunction import get_list
-from main_process import  main_process
+from .comFunction import get_list
+from .main_process import  main_process
 
 
 @Gooey(
